previewCommand<I extends Input, O extends Output> function

Future<List<Preview>> previewCommand<I extends Input, O extends Output>(
  1. Command<I, O> command
)

What command says it would do. Nothing is performed.

This is --plan, minus the rendering and the plan file — both of which belong to the framework and are tested there.

Implementation

Future<List<Preview>> previewCommand<I extends Input, O extends Output>(
  Command<I, O> command,
) async => const PreviewExecutor().preview(await command.steps());